<?php
/*
 Plugin Name: Feed reading Blogroll
 Plugin URI: http://www.weinschenker.name/plugin-feed-reading-blogroll/
 Description: This plugin lets you embed an enhanced blogroll that reads the feeds of your bookmarked sites.
 Version:  0.9.0.2
 Author: Jan Weinschenker
 Author URI: http://www.weinschenker.name


 Plugin: Copyright 2008  Jan Weinschenker  (email: kontakt@weinschenker.name)

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */


add_option('feedreading_blogroll_settings', $data, 'feedreading_blogroll Options');

/*
 * add init-action
 */
add_action('widgets_init', 'widget_init_feedreading_blogroll');
add_action('admin_menu', 'feedreading_blogroll_register_options');
add_action('wp_head', 'feedreading_blogroll_access_google');
add_action('admin_head', 'feedreading_blogroll_changelog_admin');

if (function_exists('load_plugin_textdomain')) {
	if ( !defined('WP_PLUGIN_DIR') ) {
		load_plugin_textdomain('feedreading_blogroll', str_replace( ABSPATH, '', dirname(__FILE__)));
	} else {
		load_plugin_textdomain('feedreading_blogroll', false, dirname(plugin_basename(__FILE__)));
	}
}

/*
 * initialize the widget
 */
function widget_init_feedreading_blogroll() {
	// Check for required functions
	$widget_ops = array('classname' => 'widget_feedreading_blogroll', 'description' => __('widget_feedreading_blogroll widget description ') );
	wp_register_sidebar_widget('widget_feedreading_blogroll', 'Live Blogroll', 'widget_feedreading_blogroll', $widget_ops);
	register_widget_control('widget_feedreading_blogroll', 'widget_feedreading_blogroll_control');
}


/**
 * Register with options-page
 */
function feedreading_blogroll_register_options() {
	if (function_exists('add_options_page')) {
		add_options_page('Feed reading Blogroll', 'Feed reading Blogroll', 8, basename(__FILE__), 'feedreading_blogroll_options_subpanel');
	}
}

/**
 * Get link-categories from database
 * @ return resultset containing term_id and term_id
 */
function feedreading_blogroll_get_linkcats(){
	global $wpdb;
	$cats = $wpdb->get_results("SELECT $wpdb->terms.term_ID, $wpdb->terms.name FROM $wpdb->terms join $wpdb->term_taxonomy on $wpdb->terms.term_id=$wpdb->term_taxonomy.term_id WHERE $wpdb->term_taxonomy.taxonomy = 'link_category' order by name");
	return $cats;
}

/*
 * Returns true, if new values are contained in POST-request, else false
 * @return boolean
 */
function feedreading_blogroll_vars_are_set(){
	if (isset($_POST['linkCssClass']) or isset($_POST['showLastUpdated']) or isset($_POST['showLastPostTitle']) or isset($_POST['feedreadingTitle']) or isset($_POST['showTitle']) or isset($_POST['showIcon']) or isset($_POST['defaultIcon']) or isset($_POST['googleAPIKey']) or isset($_POST['previewButton']) or isset($_POST['linkCats']) or isset($_POST['groupByLinkCats']) or isset($_POST['orderBy']) or isset($_POST['orderDirection']) or isset($_POST['displayStyle'])){
		return TRUE;
	} else {
		return FALSE;
	}
}
/*
 * read http-data and set options.
 *
 * @return array with updated plugin-options
 */
function feedreading_blogroll_setOptions() {
	$feedreading_blogroll_settings = get_option('feedreading_blogroll_settings');
	if (feedreading_blogroll_vars_are_set()) {
		$feedreading_blogroll_settings['linkCssClass']      = strip_tags(stripslashes($_POST['linkCssClass']));
		$feedreading_blogroll_settings['linkCats']          = $_POST['linkCats'];
		$feedreading_blogroll_settings['groupByLinkCats']   = strip_tags(stripslashes($_POST['groupByLinkCats']));
		$feedreading_blogroll_settings['orderBy']           = strip_tags(stripslashes($_POST['orderBy']));
		$feedreading_blogroll_settings['orderDirection']    = strip_tags(stripslashes($_POST['orderDirection']));
		$feedreading_blogroll_settings['showLastUpdated']   = strip_tags(stripslashes($_POST['showLastUpdated']));
		$feedreading_blogroll_settings['showLastPostTitle'] = strip_tags(stripslashes($_POST['showLastPostTitle']));
		$feedreading_blogroll_settings['feedreadingTitle']  = strip_tags(stripslashes($_POST['feedreadingTitle']));
		$feedreading_blogroll_settings['displayStyle']      = strip_tags(stripslashes($_POST['displayStyle']));
		$feedreading_blogroll_settings['showTitle']         = strip_tags(stripslashes($_POST['showTitle']));
		$feedreading_blogroll_settings['defaultIcon']       = strip_tags(stripslashes($_POST['defaultIcon']));
		$feedreading_blogroll_settings['showIcon']          = strip_tags(stripslashes($_POST['showIcon']));
		$feedreading_blogroll_settings['googleAPIKey']      = strip_tags(stripslashes($_POST['googleAPIKey']));
		$feedreading_blogroll_settings['previewButton']     = strip_tags(stripslashes($_POST['previewButton']));
		update_option('feedreading_blogroll_settings', $feedreading_blogroll_settings);
		$feedreading_blogroll_settings['flash'] = __('Settings saved.');
	}
	return $feedreading_blogroll_settings;
}


/*
 * render the option-panel with form
 */
function feedreading_blogroll_options_subpanel(){
	if (feedreading_blogroll_vars_are_set()) check_admin_referer('plugin-feed-reading-blogroll-action_option_panel');
	$feedreading_blogroll_settings = feedreading_blogroll_setOptions();
	$plugins                    = get_plugins();
	$cats = feedreading_blogroll_get_linkcats();

	if ($feedreading_blogroll_flash != ''){
		?>
<div id="message" class="updated fade">
<p><?php echo $feedreading_blogroll_flash; ?></p>
</div>
		<?php
	}
	?>
<div class="wrap">
<h2>Feed Reading Blogroll <?php _e('Options'); ?></h2>
<p><a href="http://www.weinschenker.name/plugin-feed-reading-blogroll/"
	target="_blank"><?php _e('Help');?></a> | <a
	href="#feedreading_blogroll_preview"><?php _e('URL-Check','feedreading_blogroll');?></a></p>

<div style="margin-top: 2em">
<h3 id="feedreading_blogroll_changelog"><?php _e('News','feedreading_blogroll');?></h3>
<div>
<p><?php _e('You are using version','feedreading_blogroll'); echo ' ' . $plugins['feed-reading-blogroll/feedreading_blogroll.php']['Version']; ?></p>
<p id="feedreading_blogroll_changelog_body"></p>
</div>
</p>
</div>

<h3><?php _e('Options'); ?></h3>

<form id="feedreading_options_form" action="" method="post"><?php
if ( function_exists('wp_nonce_field') )
wp_nonce_field('plugin-feed-reading-blogroll-action_option_panel');
?>

<table class="form-table">
	<tr>
		<th scope="row" valign="top"><a
			href="http://code.google.com/apis/ajaxfeeds/signup.html"><?php _e('Google API Key','feedreading_blogroll')?></a></th>
		<td><input size="80" id="googleAPIKey" name="googleAPIKey" type="text"
			value="<?php echo $feedreading_blogroll_settings['googleAPIKey']; ?>" />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Blogroll Title for sidebar widget','feedreading_blogroll')?></th>
		<td><input size="80" id="feedreadingTitle" name="feedreadingTitle"
			type="text"
			value="<?php echo $feedreading_blogroll_settings['feedreadingTitle']; ?>" />
		<p><input id="showTitle" name="showTitle" type="checkbox"
			value="showTitle"
			<?php checked('showTitle', $feedreading_blogroll_settings['showTitle']);?> />
			<?php _e('Display title above blogroll','feedreading_blogroll')?></p>
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Categories')?></th>
		<td><?php foreach ((array)$cats as $cat) { ?> <input type="checkbox"
			name="linkCats[]" value="<?php echo($cat->name); ?>"
			<?php if(!is_null($feedreading_blogroll_settings['linkCats']) and in_array($cat->name , $feedreading_blogroll_settings['linkCats'])==1){?>
			checked="checked" <?php } ?> /> <?php echo($cat->name); ?><br />
			<?php } ?></td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Group bookmarks by category','feedreading_blogroll')?></th>
		<td><input id="groupByLinkCats" name="groupByLinkCats" type="checkbox"
			value="groupByLinkCats"
			<?php checked('groupByLinkCats', $feedreading_blogroll_settings['groupByLinkCats']);?> />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Order bookmarks by','feedreading_blogroll')?></th>
		<td><select name="orderBy" id="orderBy" style="width: 300px;">
			<option value="id"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'id'); ?>>id</option>
			<option value="url"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'url'); ?>>url</option>
			<option value="name"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'name'); ?>>name</option>
			<option value="target"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'target'); ?>>target</option>
			<option value="description"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'description'); ?>>description</option>
			<option value="owner"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'owner'); ?>>owner</option>
			<option value="rating"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'rating'); ?>>rating</option>
			<option value="rel"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'rel'); ?>>rel</option>
			<option value="notes"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'notes'); ?>>notes</option>
			<option value="rss"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'rss'); ?>>rss</option>
			<option value="length"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'length'); ?>>length</option>
			<option value="rand"
			<?php selected($feedreading_blogroll_settings['orderBy'], 'rand'); ?>>rand</option>
		</select>
		<p><input id="orderDirectionASC" name="orderDirection" type="radio"
			value="ASC"
			<?php checked('ASC', $feedreading_blogroll_settings['orderDirection']);?> /><label
			for="orderDirectionASC"><?php _e('ascending','feedreading_blogroll'); ?></label><br />
		<input id="orderDirectionDESC" name="orderDirection" type="radio"
			value="DESC"
			<?php checked('DESC', $feedreading_blogroll_settings['orderDirection']);?> /><label
			for="orderDirectionDESC"><?php _e('descending','feedreading_blogroll'); ?></label>
		</p>
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Style','feedreading_blogroll')?></th>
		<td><input type="radio" name="displayStyle" value="minimal"
		<?php checked('minimal',$feedreading_blogroll_settings['displayStyle']); ?> />
		<?php _e('Minimal','feedreading_blogroll')?><br />
		<input type="radio" name="displayStyle" value="classic"
		<?php checked('classic',$feedreading_blogroll_settings['displayStyle']); ?> />
		<?php _e('Classic','feedreading_blogroll')?><br />
		<input type="radio" name="displayStyle" value="blogger"
		<?php checked('blogger',$feedreading_blogroll_settings['displayStyle']); ?> />
		<?php _e('Blogger(TM)','feedreading_blogroll')?><br />
		<input type="radio" name="displayStyle" value="banners"
		<?php checked('banners',$feedreading_blogroll_settings['displayStyle']); ?> />
		<?php _e('Banners','feedreading_blogroll')?><br />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Default icon','feedreading_blogroll');?></th>
		<td><input size="80" id="defaultIcon" name="defaultIcon" type="text"
			value="<?php echo $feedreading_blogroll_settings['defaultIcon']; ?>" />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('CSS class for links','feedreading_blogroll')?></th>
		<td><input size="80" id="linkCssClass" name="linkCssClass" type="text"
			value="<?php echo $feedreading_blogroll_settings['linkCssClass']; ?>" /><br />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Show update-information','feedreading_blogroll')?></th>
		<td><input id="showLastUpdated" name="showLastUpdated" type="checkbox"
			value="showLastUpdated"
			<?php checked('showLastUpdated', $feedreading_blogroll_settings['showLastUpdated']);?> />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Show title of latest post','feedreading_blogroll')?></th>
		<td><input id="showLastPostTitle" name="showLastPostTitle"
			type="checkbox" value="showLastPostTitle"
			<?php checked('showLastPostTitle', $feedreading_blogroll_settings['showLastPostTitle']);?> />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Show icon','feedreading_blogroll')?></th>
		<td><input id="showIcon" name="showIcon" type="checkbox"
			value="showIcon"
			<?php checked('showIcon', $feedreading_blogroll_settings['showIcon']);?> />
		</td>
	</tr>
	<tr>
		<th scope="row" valign="top"><?php _e('Enable bookmark preview','feedreading_blogroll')?></th>
		<td><input id="previewButton" name="previewButton" type="checkbox"
			value="previewButton"
			<?php checked('previewButton', $feedreading_blogroll_settings['previewButton']);?> />
		</td>
	</tr>
</table>
<p class="submit"><input name="submit"
	value="<?php _e('Save Changes'); ?>" type="submit" /></p>
<div style="margin-top: 2em"><?php widget_feedreading_admin_preview(); ?></div>
</form>
			<?php
}

/*
 * render the preview of the link-data, that is necessary to make the plugin work properly
 */
function widget_feedreading_admin_preview(){
	$feedreading_blogroll_settings = get_option('feedreading_blogroll_settings');
	$linkCssClass = $feedreading_blogroll_settings['linkCssClass'];
	$showLastUpdated = strcmp($feedreading_blogroll_settings['showLastUpdated'], 'showLastUpdated');
	$showIcon = strcmp($feedreading_blogroll_settings['showIcon'], 'showIcon');
	$defaultIcon = $feedreading_blogroll_settings['defaultIcon'];

	?>
<h3 id="feedreading_blogroll_preview"><?php _e('URL-Check','feedreading_blogroll');?></h3>

<p><?php _e('This section will tell you, if RSS-URLs or image-URLs are missing. Update-information in the blogroll can only be displayed if you have saved the necessary URLs.','feedreading_blogroll');?>
</p>

<table class="form-table">
<?php
// fetch bookmarks from wordpress
$bookmarks = get_bookmarks(feedreading_blogroll_bookmarkArgs(FALSE, ''));

foreach ((array)$bookmarks as $bookmark) {
	$name=$bookmark->link_name;
	$url=$bookmark->link_url;
	$urlFeed=$bookmark->link_rss;
	$image=$bookmark->link_image;
	?>
	<tr>
		<th scope="row" valign="top"><?php echo $name;?></th>
		<td>
		<ul>
			<li><?php _e('Web Address');?>: <a href="<?php echo $url;?>"
				target="_blank"><?php echo $url;?></a></li>
			<li><?php _e('RSS Address');?>: <?php 
			if (trim($urlFeed) != ''){
				?><a href="<?php echo $urlFeed;?>" target="_blank"><?php echo $urlFeed;?></a><?php
			} else {
				?><span style="color: red; font-weight: bold"><?php _e('Warning','feedreading_blogroll'); echo '! '.__('No RSS address! Please provide a feed-url for this bookmark!','feedreading_blogroll').' ';
				?></span> <a
				href="<?php
				echo '/wp-admin/link.php?link_id='.$bookmark->link_id.'&action=edit#linkadvanceddiv';?>"><?php _e('Edit Link');?></a><?php
			}
			?></li>
			<li><?php _e('Image Address');?>: <?php 
			if (trim($image) != ''){
				?><a href="<?php echo $image;?>" target="_blank"><?php echo $image;?></a><?php
			} else {
				?><span style="color: orange; font-weight: bold"><?php _e('Warning','feedreading_blogroll'); echo '! '.__('No image address! If you have configured a default icon, it will be used.','feedreading_blogroll').' ';
				?></span> <a
				href="<?php
				echo '/wp-admin/link.php?link_id='.$bookmark->link_id.'&action=edit#linkadvanceddiv';?>"><?php _e('Edit Link');?></a><?php
			}
			?></li>
		</ul>
		</td>
	</tr>
	<?php
}
?>
</table>
<?php
}

/*
 * Render the widget-body
 */
function widget_feedreading_blogroll($args) {
	extract($args);
	echo $before_widget;
	widget_feedreading_blogroll_content($before_title, $after_title);
	echo $after_widget;
}


/*
 * Render the widget-control
 */
function widget_feedreading_blogroll_control(){
	$feedreading_blogroll_settings = feedreading_blogroll_setOptions();
	$linkCssClass                  = $feedreading_blogroll_settings['linkCssClass'];
	$linkCats                      = $feedreading_blogroll_settings['linkCats'];
	$feedreadingTitle              = $feedreading_blogroll_settings['feedreadingTitle'];
	$showLastUpdated               = $feedreading_blogroll_settings['showLastUpdated'];
	$showLastPostTitle             = $feedreading_blogroll_settings['showLastPostTitle'];
	$defaultIcon                   = $feedreading_blogroll_settings['defaultIcon'];
	$showIcon                      = $feedreading_blogroll_settings['showIcon'];
	$googleAPIKey                  = $feedreading_blogroll_settings['googleAPIKey'];
	$previewButton                 = $feedreading_blogroll_settings['previewButton'];
	$cats = feedreading_blogroll_get_linkcats();
	?>
<p></p>
<p><label for="googleAPIKey"><a
	href="http://code.google.com/apis/ajaxfeeds/signup.html"><?php _e('Google API Key','feedreading_blogroll')?></a><input
	style="width: 250px;" id="googleAPIKey" name="googleAPIKey" type="text"
	value="<?php echo $googleAPIKey; ?>" /></label></p>
<p><label for="feedreadingTitle"><?php _e('Title')?> <input
	style="width: 250px;" id="feedreadingTitle" name="feedreadingTitle"
	type="text" value="<?php echo $feedreadingTitle; ?>" /></label></p>
<p><label for="showTitle"><?php _e('Display title above blogroll','feedreading_blogroll')?><br />
<input id="showTitle" name="showTitle" type="checkbox" value="showTitle"
<?php checked('showTitle', $feedreading_blogroll_settings['showTitle']);?> /></label></p>
<p><?php _e('Categories')?><br />
<?php foreach ((array)$cats as $cat) { ?> <input type="checkbox"
	name="linkCats[]" value="<?php echo($cat->name); ?>"
	<?php if(in_array($cat->name , $feedreading_blogroll_settings['linkCats'])==1){?>
	checked="checked" <?php } ?> /> <?php echo($cat->name); ?><br />
	<?php } ?></p>
<p><label for="groupByLinkCats"><?php _e('Group bookmarks by category','feedreading_blogroll')?><br />
<input style="width: 250px;" id="groupByLinkCats" name="groupByLinkCats"
	type="checkbox" value="groupByLinkCats"
	<?php checked('groupByLinkCats', $feedreading_blogroll_settings['groupByLinkCats']);?> /></label></p>
<p><label for="orderBy"><?php _e('Order bookmarks by','feedreading_blogroll')?><br />
<select name="orderBy" id="orderBy" style="width: 250px;">
	<option value="id"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'id'); ?>>id</option>
	<option value="url"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'url'); ?>>url</option>
	<option value="name"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'name'); ?>>name</option>
	<option value="target"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'target'); ?>>target</option>
	<option value="description"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'description'); ?>>description</option>
	<option value="owner"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'owner'); ?>>owner</option>
	<option value="rating"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'rating'); ?>>rating</option>
	<option value="rel"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'rel'); ?>>rel</option>
	<option value="notes"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'notes'); ?>>notes</option>
	<option value="rss"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'rss'); ?>>rss</option>
	<option value="length"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'length'); ?>>length</option>
	<option value="rand"
	<?php selected($feedreading_blogroll_settings['orderBy'], 'rand'); ?>>rand</option>
</select></label><br />
<input id="orderDirectionASC" name="orderDirection" type="radio"
	value="ASC"
	<?php checked('ASC', $feedreading_blogroll_settings['orderDirection']);?> /><label
	for="orderDirectionASC"><?php _e('ascending','feedreading_blogroll'); ?></label><br />
<input id="orderDirectionDESC" name="orderDirection" type="radio"
	value="DESC"
	<?php checked('DESC', $feedreading_blogroll_settings['orderDirection']);?> /><label
	for="orderDirectionDESC"><?php _e('descending','feedreading_blogroll'); ?></label>
</p>
<p><label><?php _e('Style','feedreading_blogroll')?></label><br />
<input type="radio" name="displayStyle" value="minimal"
<?php checked('minimal',$feedreading_blogroll_settings['displayStyle']); ?> />
Minimal<br />
<input type="radio" name="displayStyle" value="classic"
<?php checked('classic',$feedreading_blogroll_settings['displayStyle']); ?> />
Classic <br />
<input type="radio" name="displayStyle" value="blogger"
<?php checked('blogger',$feedreading_blogroll_settings['displayStyle']); ?> />
Blogger(TM) <br />
<input type="radio" name="displayStyle" value="banners"
<?php checked('banners',$feedreading_blogroll_settings['displayStyle']); ?> />
Banners <br />
</p>

<p><label for="defaultIcon"><?php _e('Default icon','feedreading_blogroll')?><input
	style="width: 250px;" id="defaultIcon" name="defaultIcon" type="text"
	value="<?php echo $defaultIcon; ?>" /></label></p>
<p><label for="linkCssClass"><?php _e('CSS class for links','feedreading_blogroll')?><input
	style="width: 250px;" id="linkCssClass" name="linkCssClass" type="text"
	value="<?php echo $linkCssClass; ?>" /></label></p>
<p><label for="showLastUpdated"><?php _e('Show update-information','feedreading_blogroll')?><br />
<input style="width: 250px;" id="showLastUpdated" name="showLastUpdated"
	type="checkbox" value="showLastUpdated"
	<?php checked('showLastUpdated',$feedreading_blogroll_settings['showLastUpdated']);?> /></label>
</p>
<p><label for="showLastPostTitle"><?php _e('Show title of latest post','feedreading_blogroll')?><br />
<input style="width: 250px;" id="showLastPostTitle"
	name="showLastPostTitle" type="checkbox" value="showLastPostTitle"
	<?php checked('showLastPostTitle',$feedreading_blogroll_settings['showLastPostTitle']);?> /></label>
</p>
<p><label for="showIcon"><?php _e('Show icon','feedreading_blogroll')?><br />
<input style="width: 250px;" id="showIcon" name="showIcon"
	type="checkbox" value="showIcon"
	<?php checked('showIcon',$feedreading_blogroll_settings['showIcon']);?> /></label>
</p>
<p><label for="previewButton"><?php _e('Enable bookmark preview','feedreading_blogroll')?><br />
<input style="width: 250px;" id="previewButton" name="previewButton"
	type="checkbox" value="previewButton"
	<?php checked('previewButton',$feedreading_blogroll_settings['previewButton']);?> /></label>
</p>
<input type="hidden" id="feedreading_blogroll_settings_submit"
	name="feedreading_blogroll_settings_submit" value="1" /> <?php 
}


/*
 * Shortcut for non-widget-users. This is the actual template-tag.
 */
function feedreading_blogroll() {
	widget_feedreading_blogroll_content('<h2>','</h2>');
}

/**
 * transforms the plugin-options into an argument-string that works with the WordPress-function "get_bookmarks()"
 * @return String with arguments for the WordPress-function "get_bookmarks()"
 */
function feedreading_blogroll_bookmarkArgs($usedForGroupedBookmarks, $cat){
	$args='';
	$feedreading_blogroll_settings = get_option('feedreading_blogroll_settings');
	$feedreadingTitle = $feedreading_blogroll_settings['feedreadingTitle'];
	$linkCats = $feedreading_blogroll_settings['linkCats'];
	$orderBy = $feedreading_blogroll_settings['orderBy'];
	$orderDirection = $feedreading_blogroll_settings['orderDirection'];
	$catOption ='';
	$catDelim ='';
	if (!is_null($linkCats)) {
		foreach ((array)$linkCats as $l){
			$catOption = $catOption.$catDelim.$l;
			$catDelim =',';
		}
	}
	$args='order='.$orderDirection.'&orderby='.$orderBy;
	if (!$usedForGroupedBookmarks){
		// use all linkcats
		$args='category_name='.$catOption.'&'.$args;
	} else {
		// use single linkcat
		$args='category_name='.$cat.'&'.$args;
	}
	return $args;
}

/*
 * render content of widget
 */
function widget_feedreading_blogroll_content($before_title, $after_title){
	$feedreading_blogroll_settings = get_option('feedreading_blogroll_settings');
	$groupByLinkCats = strcmp($feedreading_blogroll_settings['groupByLinkCats'],'groupByLinkCats');
	$linkCats = $feedreading_blogroll_settings['linkCats'];

	// fetch bookmarks from wordpress
	if ( $groupByLinkCats==0){
		if (!is_null($linkCats)) {
			foreach ((array)$linkCats as $linkCat){
				$bookmarks = get_bookmarks(feedreading_blogroll_bookmarkArgs(TRUE, $linkCat));
				widget_feedreading_blogroll_list($before_title, $after_title, $bookmarks, $linkCat);
			}
		}
	} else {
		$bookmarks = get_bookmarks(feedreading_blogroll_bookmarkArgs(FALSE,''));
		widget_feedreading_blogroll_list($before_title, $after_title, $bookmarks, '');
	}
}

/**
 * render the blogroll. This is an HTML-unordered-list (<ul>...</ul>) with list-items (<li>...</li>)
 */
function widget_feedreading_blogroll_list($before_title, $after_title, $bookmarks, $title){
	$feedreading_blogroll_settings = get_option('feedreading_blogroll_settings');
	$linkCssClass = $feedreading_blogroll_settings['linkCssClass'];
	$showLastUpdated = strcmp($feedreading_blogroll_settings['showLastUpdated'], 'showLastUpdated');
	$showIcon = strcmp($feedreading_blogroll_settings['showIcon'], 'showIcon');
	$showLastPostTitle = strcmp($feedreading_blogroll_settings['showLastPostTitle'], 'showLastPostTitle');
	$showPreviewButton = strcmp($feedreading_blogroll_settings['previewButton'], 'previewButton');
	$defaultIcon = $feedreading_blogroll_settings['defaultIcon'];
	$showTitle = strcmp($feedreading_blogroll_settings['showTitle'],'showTitle');
	$displayStyle = $feedreading_blogroll_settings['displayStyle'];
	if ($title =='') $title = $feedreading_blogroll_settings['feedreadingTitle'];

	if ($showTitle == 0){
		echo $before_title;
		echo $title;
		echo $after_title;
	}
	?>
<ul>
<?php
foreach ((array)$bookmarks as $bookmark){
	// print bookmark
	if ($displayStyle=='minimal'){
		widget_feedreading_blogroll_style_minimal($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon);
	} else if ($displayStyle=='classic'){
		widget_feedreading_blogroll_style_classic($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon);
	} else if ($displayStyle=='blogger') {
		widget_feedreading_blogroll_style_blogger($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon);
	}else if ($displayStyle=='banners') {
		widget_feedreading_blogroll_style_banners($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon);
	}
}
?>
</ul>
<?php
}

/*
 * The simple display-style with name of target-blog and update-information:
 *
 *  * Blog-name
 *    * updated 3 days ago
 */
function widget_feedreading_blogroll_style_minimal($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon){
	$name=$bookmark->link_name;
	$url=$bookmark->link_url;
	$urlFeed=$bookmark->link_rss;
	$image=$bookmark->link_image;
	$xfn=$bookmark->link_rel;
	?>
<li style="margin-top: 1em !important;" class="feedreading_bookmark"
	id="feedreading_bookmark_<?php echo $bookmark->link_id;?>"><?php if (trim($image) != '' and $showIcon == 0){ 
		?><img src="<?php echo $image; ?>" style="width: 16px; height: 16px;"
	width="16" height="16" alt="Icon" />&nbsp;<?php
	} else if (trim($image) == '' and $showIcon == 0 and trim($defaultIcon) != ''){
		?><img src="<?php echo trim($defaultIcon); ?>"
	style="width: 16px; height: 16px;" width="16" height="16" alt="Icon" />&nbsp;<?php
	}
	?><a id="feedreading_anchor_<?php echo $bookmark->link_id;?>"
	href="<?php echo $url;?>" title="<?php echo $name; ?>"
	<?php if ($bookmark->link_target != '') {?>
	target="<?php echo $bookmark->link_target; ?>" <?php } ?>
	rel="external <?php echo $xfn;?>" class="<?php echo $linkCssClass; ?>"><?php echo $name; ?></a><?php
	// if bookmark has feed-info, get update-info and print it
	if (trim($urlFeed)!='' and ($showLastUpdated == 0 or $showLastPostTitle == 0)) { ?>
<div id="feedreading_info_<?php echo $bookmark->link_id;?>"
	class="lastPublicationDate" style="display: block"><abbr
	style="cursor: pointer"
	title="<?php _e('last change','feedreading_blogroll');?>"
	id="feedreading_previewtoggle_<?php echo $bookmark->link_id;?>"></abbr><abbr
	style="display: none"
	id="frbl_last_posttitle_<?php echo $bookmark->link_id;?>"></abbr></div>
<div style="display: none;"
	id="feedreading_preview_wrap_<?php echo $bookmark->link_id;?>">
<p><small style="cursor: pointer"><?php _e('Preview'); echo ' '; echo __('Close');?></small></p>
<div id="feedreading_preview_<?php echo $bookmark->link_id;?>"
	style="margin-left: 0;">Loading...</div>
</div>
	<?php
	}
	?></li>
	<?php
}

/*
 * The classic display-style with name of target-blog, update-information and unlinked title of most recent post
 *
 *  * Blog-name
 *    * updated 3 days ago: Title of most recent article
 */
function widget_feedreading_blogroll_style_classic($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon){
	$name=$bookmark->link_name;
	$url=$bookmark->link_url;
	$urlFeed=$bookmark->link_rss;
	$image=$bookmark->link_image;
	$xfn=$bookmark->link_rel;
	?>
<li style="margin-top: 1em !important;" class="feedreading_bookmark"
	id="feedreading_bookmark_<?php echo $bookmark->link_id;?>"><?php if (trim($image) != '' and $showIcon == 0){ 
		?><img src="<?php echo $image; ?>" style="width: 16px; height: 16px;"
	width="16" height="16" alt="Icon" />&nbsp;<?php
	} else if (trim($image) == '' and $showIcon == 0 and trim($defaultIcon) != ''){
		?><img src="<?php echo trim($defaultIcon); ?>"
	style="width: 16px; height: 16px;" width="16" height="16" alt="Icon" />&nbsp;<?php
	}
	?><a id="feedreading_anchor_<?php echo $bookmark->link_id;?>"
	href="<?php echo $url;?>" title="<?php echo $name; ?>"
	<?php if ($bookmark->link_target != '') {?>
	target="<?php echo $bookmark->link_target; ?>" <?php } ?>
	rel="external <?php echo $xfn;?>" class="<?php echo $linkCssClass; ?>"><?php echo $name; ?></a><?php
	// if bookmark has feed-info, get update-info and print it
	if (trim($urlFeed)!='' and ($showLastUpdated == 0 or $showLastPostTitle == 0)) { ?>
<div id="feedreading_info_<?php echo $bookmark->link_id;?>"
	class="lastPublicationDate" style="display: block"><abbr
	style="cursor: pointer"
	title="<?php _e('last change','feedreading_blogroll');?>"
	id="feedreading_previewtoggle_<?php echo $bookmark->link_id;?>"></abbr>:
<abbr style="" id="frbl_last_posttitle_<?php echo $bookmark->link_id;?>"></abbr></div>
<div style="display: none;"
	id="feedreading_preview_wrap_<?php echo $bookmark->link_id;?>">
<p><small style="cursor: pointer"><?php _e('Preview'); echo ' '; echo __('Close');?></small></p>
<div id="feedreading_preview_<?php echo $bookmark->link_id;?>"
	style="margin-left: 0;">Loading...</div>
</div>
	<?php
	}
	?></li>
	<?php
}

/*
 * The Blogger(TM)-like display-style with name of target-blog, update-information and link to most recent article:
 *
 *  * Blog-name
 *    * Link to most recent article
 *    * updated 3 days ago
 */
function widget_feedreading_blogroll_style_blogger($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon){
	$name=$bookmark->link_name;
	$url=$bookmark->link_url;
	$urlFeed=$bookmark->link_rss;
	$image=$bookmark->link_image;
	$xfn=$bookmark->link_rel;
	?>
<li style="margin-bottom: 1em !important;" class="feedreading_bookmark"
	id="feedreading_bookmark_<?php echo $bookmark->link_id;?>"><?php if (trim($image) != '' and $showIcon == 0){ 
		?><img src="<?php echo $image; ?>" style="width: 16px; height: 16px;"
	width="16" height="16" alt="Icon" />&nbsp;<?php
	} else if (trim($image) == '' and $showIcon == 0 and trim($defaultIcon) != ''){
		?><img src="<?php echo trim($defaultIcon); ?>"
	style="width: 16px; height: 16px;" width="16" height="16" alt="Icon" />&nbsp;<?php
	}
	?><a id="feedreading_anchor_<?php echo $bookmark->link_id;?>"
	href="<?php echo $url;?>" title="<?php echo $name; ?>"
	<?php if ($bookmark->link_target != '') {?>
	target="<?php echo $bookmark->link_target; ?>" <?php } ?>
	rel="external <?php echo $xfn;?>" class="<?php echo $linkCssClass; ?>"><?php echo $name; ?></a><?php
	// if bookmark has feed-info, get update-info and print it
	if (trim($urlFeed)!='' and ($showLastUpdated == 0 or $showLastPostTitle == 0)) { ?>
<div id="feedreading_info_<?php echo $bookmark->link_id;?>"
	class="lastPublicationDate" style="display: block">
<p style="margin: 0; font-weight: bold;" class="frbl_last_posttitle"><a
	href="" id="frbl_last_posttitle_<?php echo $bookmark->link_id;?>"
	<?php if ($bookmark->link_target != '') {?>
	target="<?php echo $bookmark->link_target; ?>" <?php } ?>></a></p>
<abbr style="cursor: pointer; margin-bottom: 1em"
	title="<?php _e('last change','feedreading_blogroll');?>"
	id="feedreading_previewtoggle_<?php echo $bookmark->link_id;?>"></abbr></div>
<div style="display: none;"
	id="feedreading_preview_wrap_<?php echo $bookmark->link_id;?>">
<p><small style="cursor: pointer"><?php _e('Preview'); echo ' '; echo __('Close');?></small></p>
<div id="feedreading_preview_<?php echo $bookmark->link_id;?>"
	style="margin-left: 0;">Loading...</div>
</div>
	<?php
	}
	?></li>
	<?php
}

/*
 * The banner display-style with banner of target-blog, update-information and link to most recent article:
 *
 *  * Blog-banner (Text-Link if no banner-url is supplied)
 *    * Link to most recent article
 *    * updated 3 days ago
 */
function widget_feedreading_blogroll_style_banners($bookmark,$linkCssClass,$showLastUpdated,$showIcon,$showLastPostTitle,$showPreviewButton,$defaultIcon){
	$name=$bookmark->link_name;
	$url=$bookmark->link_url;
	$urlFeed=$bookmark->link_rss;
	$image=$bookmark->link_image;
	$xfn=$bookmark->link_rel;
	?>
<li style="margin-bottom: 1em !important;" class="feedreading_bookmark"
	id="feedreading_bookmark_<?php echo $bookmark->link_id;?>"><a
	id="feedreading_anchor_<?php echo $bookmark->link_id;?>"
	href="<?php echo $url;?>" title="<?php echo $name; ?>"
	<?php if ($bookmark->link_target != '') {?>
	target="<?php echo $bookmark->link_target; ?>" <?php } ?>
	rel="external <?php echo $xfn;?>" class="<?php echo $linkCssClass; ?>"><?php if (trim($image) != '' and $showIcon == 0){ 
		?><img src="<?php echo $image; ?>" alt="<?php echo $name; ?>" /><?php
	} else if (trim($image) == '' and $showIcon == 0 and trim($defaultIcon) != ''){
		?><?php echo $name; ?><?php
	}
	?></a><?php
	// if bookmark has feed-info, get update-info and print it
	if (trim($urlFeed)!='' and ($showLastUpdated == 0 or $showLastPostTitle == 0)) { ?>
<div id="feedreading_info_<?php echo $bookmark->link_id;?>"
	class="lastPublicationDate" style="display: block">
<p style="margin: 0; font-weight: bold;" class="frbl_last_posttitle"><a
	href="" id="frbl_last_posttitle_<?php echo $bookmark->link_id;?>"
	<?php if ($bookmark->link_target != '') {?>
	target="<?php echo $bookmark->link_target; ?>" <?php } ?>></a></p>
<abbr style="cursor: pointer; margin-bottom: 1em"
	title="<?php _e('last change','feedreading_blogroll');?>"
	id="feedreading_previewtoggle_<?php echo $bookmark->link_id;?>"></abbr></div>
<div style="display: none;"
	id="feedreading_preview_wrap_<?php echo $bookmark->link_id;?>">
<p><small style="cursor: pointer"><?php _e('Preview'); echo ' '; echo __('Close');?></small></p>
<div id="feedreading_preview_<?php echo $bookmark->link_id;?>"
	style="margin-left: 0;">Loading...</div>
</div>
	<?php
	}
	?></li>
	<?php
}

/*
 * HTML for the blog's header-section, containing the necessary Javascript to access the Google API
 */
function feedreading_blogroll_access_google(){
	$feedreading_blogroll_settings = get_option('feedreading_blogroll_settings');
	$googleAPIKey = $feedreading_blogroll_settings['googleAPIKey'];
	$bookmarks = get_bookmarks(feedreading_blogroll_bookmarkArgs(FALSE,''));
	$showLastUpdated = strcmp($feedreading_blogroll_settings['showLastUpdated'], 'showLastUpdated');
	$showLastPostTitle = strcmp($feedreading_blogroll_settings['showLastPostTitle'], 'showLastPostTitle');
	$showPreviewButton = strcmp($feedreading_blogroll_settings['previewButton'], 'previewButton');
	if ($showLastUpdated == 0 or $showLastPostTitle == 0){ ?><script
	type="text/javascript"
	src="http://www.google.com/jsapi?key=<?php echo $googleAPIKey;?>"></script>
<script type="text/javascript">/* <![CDATA[ */
          google.load("feeds", "1"); 
            function initializeBR() {<?php    
                foreach ((array)$bookmarks as $bookmark){
                    $urlFeed=$bookmark->link_rss;
                    $name=$bookmark->link_name;
                    
                    if(trim($bookmark->link_rss)!='') {?>
                var feed = new google.feeds.Feed("<?php echo $urlFeed; ?>");
                  feed.load(function(result){
                    if (!result.error) {
                        addAge(result.feed.entries[0], "feedreading_bookmark_<?php echo $bookmark->link_id;?>", "feedreading_anchor_<?php echo $bookmark->link_id;?>", "feedreading_info_<?php echo $bookmark->link_id;?>", "feedreading_previewtoggle_<?php echo $bookmark->link_id;?>", "frbl_last_posttitle_<?php echo $bookmark->link_id;?>"); <?php
                            if ($showPreviewButton==0){?>
                        addObserver("feedreading_previewtoggle_<?php echo $bookmark->link_id?>", "feedreading_preview_wrap_<?php echo $bookmark->link_id;?>", "feedreading_preview_<?php echo $bookmark->link_id;?>", "<?php echo $urlFeed; ?>", "<?php echo $name; ?>");<?php } // end if 
?>
                    }
                  });
                  <?php } // end if ?>
                <?php } // end foreach ?>
            }

            /*
             * generate text showing the age of the bookmark's latest post
             */
            function getAge(days, hours){
                if (days > 1) {
                    var ageMsg=days + " <?php _e('days ago','feedreading_blogroll') ?>";
                } else if (days==1){
                    var ageMsg=days + " <?php _e('day ago','feedreading_blogroll') ?> ";                    
                } else if (days< 1 && hours > 1) {
                    var ageMsg=hours + " <?php _e('hrs ago','feedreading_blogroll') ?>";                                        
                } else if (days< 1 && hours == 1) {
                    var ageMsg=hours + " <?php _e('hr ago','feedreading_blogroll') ?>";                                        
                } else if (days < 1 && hours < 1) {
                    var ageMsg=hours + " <?php _e('just recently','feedreading_blogroll') ?>";                                        
                }
                return ageMsg;
            }
            /* switch visibility of div-element*/
            function divSwitcher(elementId){
                var div = document.getElementById(elementId);
                if(div.style.display == "block"){
                    div.style.display = "none";
                } else {
                    div.style.display = "block";
                }
            }
            /* add jQuery-oberserver to enable mouse-clicks*/
            function addObserver(link, wrapper, preview, feed, name){                
                jQuery("#"+link).click(function(){
                    divSwitcher(wrapper);
                    var feedControl = new google.feeds.FeedControl();
                    feedControl.addFeed(feed, name);
                    feedControl.draw(document.getElementById(preview));
                });
                jQuery("#"+wrapper).click(function(){
                    divSwitcher(wrapper);
                });
            }
            /* add age and other info to bookmark*/
            function addAge(entry, bookmark, anchor, divID, previewtoggle, last_posttitle){
                var li = document.getElementById(bookmark);
                var a = document.getElementById(anchor);
                var div = document.getElementById(divID);
                var toggle = document.getElementById(previewtoggle);
                var title = document.getElementById(last_posttitle);
                var now = new Date();
                try {
                    var then = new Date(entry.publishedDate);
                } catch (dateException) {
                    var then = new Date();
                }
                var ageInDays =  Math.floor((now.getTime()-then.getTime())/(1000*60*60*24));
                var ageInHours = Math.floor((now.getTime()-then.getTime())%(1000*60*60*24)/3600000);
                try {
                    a.setAttribute("title", entry.title);
                } catch (titleException) {
                    a.setAttribute("title", "");
                }
                <?php if ($showLastUpdated==0) { ?>
                if (isNaN(ageInDays) || isNaN(ageInHours)){
                    // do nothing
                } else {
                    var ageMsg=getAge(ageInDays, ageInHours);
                    toggle.appendChild(document.createTextNode(ageMsg));
                }
                <?php } ?>
                <?php if ($showLastPostTitle==0) { ?>
                    title.appendChild(document.createTextNode(entry.title));
                    title.setAttribute("href",entry.link);
                    title.setAttribute("title",entry.contentSnippet);
                    title.setAttribute("rel","external");                    
                <?php } ?>
            }
            google.setOnLoadCallback(initializeBR);
          /* ]]> */
        </script>
<style type="text/css">
/* <![CDATA[ */
li.feedreading_bookmark div {
	margin-left: 0 !important;
}
/* ]]>*/
</style>

                <?php
	}
}

/*
 * Adds a Javascript to the header in the admin section to display the plugin's changelog
 */
function feedreading_blogroll_changelog_admin() {
	$feedreading_blogroll_settings = get_option('feedreading_blogroll_settings');
	$googleAPIKey = $feedreading_blogroll_settings['googleAPIKey'];?> <script
	type="text/javascript"
	src="http://www.google.com/jsapi?key=<?php echo $googleAPIKey;?>"></script>
<script type="text/javascript">/* <![CDATA[ */
          google.load("feeds", "1"); 
            function initialize() {
                 var feedControl = new google.feeds.FeedControl();
                 feedControl.addFeed("http://www.weinschenker.name/forum/rss/topic/changelog","Release Notes");
                 feedControl.addFeed("http://www.weinschenker.name/forum/rss/forum/feed-reading-blogroll-developer-notes/topics","Developer Notes");
                 feedControl.setNumEntries(1);
                 feedControl.setLinkTarget(google.feeds.LINK_TARGET_BLANK);
                 feedControl.draw(document.getElementById("feedreading_blogroll_changelog_body"),
                   {
                    drawMode : google.feeds.FeedControl.DRAW_MODE_TABBED
                   }
                 );
              }            
            google.setOnLoadCallback(initialize);
          /* ]]> */
        </script> <?php
}
?>